View source: R/test_dataset_retentionmort.R
| test_dataset_retentionmort | R Documentation |
Using the example code verbatim, this function will produce a series of outputs that can be directly input into the retentionmort() function.
test_dataset_retentionmort()
c = One value for the total number of tagging efforts that is 6 or greater.
err = A value (between 1 and 26) that represents the weekly mortality rate and weekly tag loss rate from a preloaded case study listed in the metadata.
n_c1 = A vector of the number of tagged individuals in one of two categorical variables.
nT = A vector of the number of tagged individuals for each tagging effort.
R = A vector of the number of recaptured individuals per effort.
TaL = A vector of the cumulative number of tagged individuals following each effort.
#Run this verbatim to produce a single mark-recapture dataset
ret_env <- new.env()
data<- test_dataset_retentionmort()
list2env(data, envir = ret_env)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.